<?php

namespace Drp\SimpleCms\Generators;

use Illuminate\Filesystem\Filesystem;
use Illuminate\Support\Str;

class ViewCreator
{
    /**
     * @var \Illuminate\Filesystem\Filesystem
     */
    protected $files;

    public function __construct(Filesystem $files)
    {
        $this->files = $files;
    }

    public function create(string $path): void
    {
        $this->makeDirectory($path);

        foreach ($this->getStubs() as $stubName => $stub) {
            $this->files->put(
                $this->getPath($stubName, $path),
                $stub
            );
        }
    }

    protected function getStubs(): array
    {
        return [
            'create-form-fields' => $this->files->get($this->stubPath() . '/create-form-fields.stub'),
            'form-fields' => $this->files->get($this->stubPath() . '/form-fields.stub'),
        ];
    }

    protected function getPath(string $name, string $path): string
    {
        return $path . DIRECTORY_SEPARATOR . $name . '.blade.php';
    }

    public function stubPath(): string
    {
        return __DIR__ . DIRECTORY_SEPARATOR . 'stubs';
    }

    protected function getClassName(string $name): string
    {
        return Str::studly($name);
    }

    protected function makeDirectory(string $path): void
    {
        if ($this->files->isDirectory($path) === true) {
            return;
        }

        $this->files->makeDirectory($path, 0755, true);
    }
}
