<?php

namespace Drp\SimpleCms\Test\Unit;

use Drp\SimpleCms\Contracts\Publishable;
use Drp\SimpleCms\Scopes\PreviewScope;
use Drp\SimpleCms\Test\Support\Fakes\TestContent;
use Drp\SimpleCms\Test\TestCase;

/**
 * Class PreviewTest
 * @package Drp\SimpleCms\Test\Unit
 */
class PreviewTest extends TestCase
{
    /**
     * @test
     */
    public function it_returns_all_versions_of_content_unscoped()
    {
        factory(TestContent::class)
            ->states(Publishable::STATUS_PUBLISHED)
            ->create();

        $draftContent = factory(TestContent::class)
            ->states(Publishable::STATUS_DRAFT)
            ->create(['content_id' => 1]);

        $results = $draftContent->allVersionsOfContent;
        $this->assertCount(2, $results);
    }

    /**
     * @test
     */
    public function it_returns_content_with_no_draft_or_review_content()
    {
        factory(TestContent::class)
            ->states(Publishable::STATUS_DRAFT)
            ->create();

        $this->assertEmpty(TestContent::hasNoDraftOrInReview()->get());

        factory(TestContent::class)
            ->states(Publishable::STATUS_REVIEW)
            ->create();

        $this->assertEmpty(TestContent::hasNoDraftOrInReview()->get());

        $content = factory(TestContent::class)
            ->states(Publishable::STATUS_PUBLISHED)
            ->create();

        $this->assertSameModel($content, TestContent::hasNoDraftOrInReview()->get()->first());
    }


    /** @test */
    public function the_preview_scope_can_be_applied_content()
    {
        $content = factory(TestContent::class)
            ->states(Publishable::STATUS_PUBLISHED)
            ->create();

        $draftContent = factory(TestContent::class)
            ->states(Publishable::STATUS_DRAFT)
            ->create(['content_id' => 1]);

        $content2 = factory(TestContent::class)
            ->states(Publishable::STATUS_PUBLISHED)
            ->create();

        $results = TestContent::all();

        $this->assertCount(3, $results);

        TestContent::addGlobalScope(new PreviewScope);

        $results = TestContent::all();

        $this->assertCount(2, $results);
        $this->assertNotContainsModel($content, $results); // This published content is not returned because there is a draft
        $this->assertContainsModel($draftContent, $results);
        $this->assertContainsModel($content2, $results);
    }


}
